//<createIBMPracticesSEProject.inc>

/*
    Create IBMPractices/SE Project
    
    Version: 1.2
    Author:  GSR
*/

/*
    CHANGE LOG
    
    When	Who	What
    --------------------------------------------------------------------------------------------------
    20080918	GSR	Converted from IBMPractices/ESW to IBMPractices/SE (new version 1.2)
    20070711	BW	Converted from OpenUP to IBMPractices/ESW (new version: 1.1)
    20070625	RJH	Refactored & reorganised code, clean-up after blocking DB.
    20070925	AF	Added check for illegal characters in name and description
*/


//////////////////////////////////////
// Pragmas

pragma runLim, 0
#include <project/IBMPracticesSE/IBMPracticesSEglobals.inc>
#include <project/IBMPracticesSE/Restore Refs.inc>


//////////////////////////////////////
// Local declarations / initialisation

const string templateType = "IBMPractices/SE"
const string templateName = "Rational_IBMPracticesSE_Standard_Template.dpa"

DB  instanceNameBox
DBE nameBox, descriptionBox

string processTemplateDirectory = strEmpty
string restoreError             = strEmpty
string projectName              = strEmpty
string templateInstanceName     = strEmpty
string templateInstanceDesc     = strEmpty
string confFileName             = strEmpty


//////////////////////////////////////
// Auxiliary Functions

void getProcessTemplateDirectoryForProject()
{
	if (confFileExists (confFileName, confSystem))
	{
		ConfStream inputStream = confRead (confFileName, confSystem)
		inputStream >> processTemplateDirectory
		close inputStream
	}
	else
	{
		infoBox "New Project will use the default IBMPractices/SE templates in the DOORS program folder."
		processTemplateDirectory = defaultPathToTemplates
	}
}

void doTemplateRestore()
{
	getProcessTemplateDirectoryForProject()
	
	string fileName = processTemplateDirectory templateName
	string projName
	string projDesc
	Date archiveDate
	
	getProjectDetails(fileName, projName, projDesc, archiveDate)

	//restoreError = restoreProject ((processTemplateDirectory templateName strEmpty), templateInstanceName, templateInstanceDesc, false)
	restoreError = restoreProject ((processTemplateDirectory templateName strEmpty), projName, templateInstanceDesc, false)

	if (!null restoreError)
	{
		errorBox (restoreErrorMessage restoreError strEmpty)
	}
	else
	{
		restoreRefs(projName)
		Project p = project(projName)
		rename(p, templateInstanceName, templateInstanceDesc)
		refreshDBExplorer
		infoBox("Restore complete.")
	}
}


//////////////////////////////////////
// DB/DBE Callbacks

void doRestoreTemplate(DB instanceNameBox) 
{
    templateInstanceName = get nameBox
    templateInstanceDesc = get descriptionBox
    bool namecheck = NameValidation(instanceNameBox, templateInstanceName)
    bool desccheck = DescValidation(instanceNameBox, templateInstanceDesc)
    Item iref
    
    if(namecheck && desccheck)
    {
    	iref = item("/" templateInstanceName)
    	if(!null(iref) && type(iref) == "Project")
    	{
    		ack("A project with the name " templateInstanceName " already exists.\n Please choose a different name and try again.")
    	}
    	else
    	{
			doTemplateRestore()
			release instanceNameBox
			instanceNameBox = null
			halt
		}
    }
}

void doClose (DB instanceNameBox)
{
    release instanceNameBox
	instanceNameBox = null
	halt
}


//////////////////////////////////////
// Main Program

if (!null (current Project))
{	
	projectName  = name (current Project)
}

confFileName = projectName "_IBMPracticesSE_Template_Directory" strEmpty

instanceNameBox = create ("Create " templateType " Project", styleCentered)
nameBox         = field (instanceNameBox, "New Project Name:", "New Project", 30)
descriptionBox  = field (instanceNameBox, "New Project Description:", "IBMPractices SE Project", 30)

ok (instanceNameBox, "Create", doRestoreTemplate)
close (instanceNameBox, true, doClose)
block instanceNameBox