//<createDocs.inc>

/*
    IBMPractices/SE Template Insantiation
    
    Version: 1.3
    Author:  Geoff Rosenthal
*/

/*
    CHANGE LOG
    
    When        Who     What
    --------------------------------------------------------------------------------------------------
    20080918    GSR     Modified IBMPractices/ESW latest version to work for IBMPractices/SE (new version 1.3)
    20070914	BW	Modified Module Name dialog to inform user that document will be created in current location in DOORS DB Explorer
    20070711	BW	Converted from OpenUP to IBMPractices/ESW (new version: 1.1)
    20070625    RJH     Refactored & reorganised code, clean-up after blocking DB.
    20070925	AF	Added check for illegal characters in specified module name
*/

//////////////////////////////////////
// Pragmas

pragma runLim, 0
//#include <project/IBMPractices/IBMPracticesglobals.inc>


//////////////////////////////////////
// Local declarations / initialisation

string templateInstanceName = strEmpty
string restoreError         = strEmpty
string projectName          = strEmpty
string confFileName         = strEmpty
string processTemplateDirectory
bool canCreate = false
Folder f = null

DB  instanceNameBox
DBE fieldLabel, nameBox


//////////////////////////////////////
// Auxiliary Functions

void getProcessTemplateDirectoryForProject()
{
	if (confFileExists (confFileName, confSystem))
	{
		ConfStream inputStream = confRead (confFileName, confSystem)
		inputStream >> processTemplateDirectory
		close inputStream
	}
	else
	{
		infoBox "No Custom Template Directory has been set for the " projectName " Project.\nRestore will use the default templates installed locally."
		processTemplateDirectory = defaultPathToTemplates
	}
}

void doTemplateRestore()
{
	/*
	getProcessTemplateDirectoryForProject()
	//set the correct folder first
	f = folder("/" projectName templatePath)
	current = f
	restoreError = restoreModule ((processTemplateDirectory "\\" templateName strEmpty), templateInstanceName, false)

	if (!null restoreError)
	{
		ack (restoreErrorMessage restoreError strEmpty)
		halt
	}

	string modFullName = "/" projectName templatePath "/" templateInstanceName
	ModName_ m = module(modFullName) 
	setLinkModuleDescriptorsExclusive(f, m, true)
	*/
	f = folder("/" projectName templatePath)
	current = f
	Item iref = item("/" projectName templateTgt)
	
	f = folder("/" projectName templateTgtPath)
	
	clipCopy(iref)
	clipPaste(f)
	
	iref = item("/" projectName templateTgtPath "/" templateName)
	
	rename(iref, templateInstanceName, "")
	refreshDBExplorer
}


//////////////////////////////////////
// DB/DBE Callbacks

void doRestoreTemplate(DB instanceNameBox) 
{
	Item iref
	
    templateInstanceName = get nameBox
    bool namecheck = NameValidation(instanceNameBox, templateInstanceName)
    if(namecheck)
    {
    	iref = item("/" projectName templateTgtPath "/" templateInstanceName)
    	
    	if(!null(iref) && type(iref) == "Formal")
    	{
    		ack("A formal module with the name " templateInstanceName " already exists.\n Please choose a different name and try again.")    		
    		canCreate = false
    	}
    	else
    	{
			doTemplateRestore()
			release instanceNameBox
			instanceNameBox = null
			canCreate = true
		}
    }
}

void doClose (DB instanceNameBox)
{
    release instanceNameBox
	instanceNameBox = null
	halt
}


//////////////////////////////////////
// Main Program

if(!null (current Project))
{	
	projectName  = name (current Project)
	confFileName = projectName "_IBMPracticesSE_Template_Directory" strEmpty
}
else
{
	errorBox "You must be inside a Project to run this utility."
	halt
}



// main

instanceNameBox = create ("Create " templateType " Instance", styleCentered|styleFloating)
fieldLabel      = label (instanceNameBox, "Note: The document will be created in the appropriate folder in the current Project.\n\n" templateType " Module Name:")
nameBox         = field (instanceNameBox, null, "", 40)
nameBox->"right"->"form"

ok (instanceNameBox, "Create", doRestoreTemplate)
close (instanceNameBox, true, doClose)
block instanceNameBox