//<setProcessWebsite.inc>

/*
    Set Project Specific IBMPractices/SE Process Website
    
    Version: 1.2
    Author:  BW
*/

/*
    CHANGE LOG
    
    When        Who     What
    -------------------------------------------------------------------------
    20080918	GSR	Converted from IBMPractices/ESW to IBMPractices/SE (new version: 1.2)
    20070711	BW	Converted from OpenUP to IBMPractices/ESW (new version: 1.1)
    20070625    RJH     Refactored & reorganised code.
    20070626    RJH     Display last URL set for project as default in DB
                        Apply simple validation
    20070925	AF	Corrected regexp
*/


//////////////////////////////////////
// Pragmas

pragma runLim, 0
#include <project/IBMPractices/IBMPracticesglobals.inc>

//////////////////////////////////////
// Local declarations / initialisation

string projectName       = strEmpty
string confFileName      = strEmpty
string processWebsiteURL = strEmpty

DB processWebsiteNameBox
DBE descriptionLabel, nameBox

//////////////////////////////////////
// Auxiliary Functions

bool isValidURL (string inputURL)
{
    //Regexp rexValidURL = regexp "^http[s]*\\://[^.]+/$"
	Regexp rexValidURL = regexp "(^http|https)(://)([^ \\),;>\"]*)(/$)"
    
    if (rexValidURL lower(inputURL))
    {
        return true
    }
    else
    {
        return false
    }
}

void setProcessWebsiteForProject()
{
	ConfStream outputStream = confWrite (confFileName, confSystem)
	outputStream << processWebsiteURL ""
	close outputStream

	//infoBox ("Process Website for the " projectName " Project\nhas been successfully set to " processWebsiteURL "")
}

string getProcessWebsiteForProject()
{
	if (confFileExists (confFileName, confSystem)) then
	{
		ConfStream inputStream = confRead (confFileName, confSystem)
		inputStream >> processWebsiteURL
		close inputStream

		return processWebsiteURL
	}
	else
	{
	    processWebsiteURL = "http://"
		return processWebsiteURL
	}
}


//////////////////////////////////////
// DB/DBE Callbacks

void doSetWebsite(DB processWebsiteNameBox) 
{
    processWebsiteURL = get nameBox
    
    if (isValidURL processWebsiteURL) then
    {
        setProcessWebsiteForProject()
    }
    else
    {
        errorBox "An invalid URL was specified.\n
        The specified URL must begin with either 'http://' or 'https://', and end with a '/'.
        It must contain the full path to the relevant virtual directory, including the fully-qualified
        domain name (or IP address) of the server.
        Do not include the name of the target page (e.g. 'index.html')"
    }

    
    release processWebsiteNameBox
	processWebsiteNameBox = null
}

void doClose (DB processWebsiteNameBox)
{
    release processWebsiteNameBox
	processWebsiteNameBox = null
}


//////////////////////////////////////
// Main Program

if(!null (current Project))
{	
	projectName  = name (current Project)
	confFileName = projectName "_Process_Website" strEmpty
}
else
{
	errorBox "You must be inside a Project to run this utility."
	halt
}
          
processWebsiteNameBox = create ("Set Process Website for Project", styleCentered)
descriptionLabel      = label (processWebsiteNameBox, ("Please enter a URL to the published Process Website for the '" projectName "' Project.\n\nThis should be the URL path to the website root (including the trailing slash), where the index.html file resides.\n(The path itself should not contain the 'index.html' file.)"))
nameBox               = field (processWebsiteNameBox, "Process Website URL:", getProcessWebsiteForProject(), 55)
nameBox->"right"->"form"

apply (processWebsiteNameBox, ("Set", doSetWebsite))
close (processWebsiteNameBox, true, doClose)
block processWebsiteNameBox